from sedaro_base_client.paths.simulations_branches_branch_id_control_.get import ApiForget
from sedaro_base_client.paths.simulations_branches_branch_id_control_.post import ApiForpost


class SimulationsBranchesBranchIdControl(
    ApiForget,
    ApiForpost,
):
    pass
