from sedaro_base_client.paths.models_branches_current_branch_id_merge_incoming_branch_id.post import ApiForpost


class ModelsBranchesCurrentBranchIdMergeIncomingBranchId(
    ApiForpost,
):
    pass
