from sedaro_base_client.paths.simulations_jobs_job_id_externals_agent_id_external_state_block_id.get import ApiForget
from sedaro_base_client.paths.simulations_jobs_job_id_externals_agent_id_external_state_block_id.patch import ApiForpatch


class SimulationsJobsJobIdExternalsAgentIdExternalStateBlockId(
    ApiForget,
    ApiForpatch,
):
    pass
